# OpenAI Server-Sent Events plugin for LiveKit Agents

Support for OpenAI SSE TTS API.

## Installation

```bash
pip install git+https://github.com/livex-ai/livekit-plugins-openai-sse.git
```

## Pre-requisites

You'll need an API key from OpenAI. It can be set as an environment variable: `OPENAI_API_KEY`
